import { getAssignmentList } from "@/app/lib/assignment/action";
import { getBatches } from "@/app/lib/batches/action";
import { usersRequestList } from "@/app/lib/users/action";
import { SearchParamProps } from "@/types/searchParams";
import { prepareBatchesDropdown, prepareUsersDropdown } from "@/utils/common";
import { Box } from "@chakra-ui/react";
import TransferForm from "./components/form";

const Transfer = async ({ searchParams }: SearchParamProps) => {
  const [users, batches, assignments] = await Promise.all([
    usersRequestList({ pagination: "false" }),
    getBatches({ pagination: "false" }),
    searchParams.user_ids 
      ? getAssignmentList({ 
          ...searchParams, 
          pagination: "false", 
          limit: 100,
          attempt: "false",
        }) 
      : Promise.resolve({ data: [] }),
  ]);

  const usersDropdown = prepareUsersDropdown(users);
  const batchesDropdown = prepareBatchesDropdown(batches);

  return (
    <Box pt={{ base: "130px", md: "80px", xl: "80px" }} mb="20px">
      <TransferForm 
        usersDropdown={usersDropdown} 
        batchesDropdown={batchesDropdown} 
        assignments={assignments?.data ?? []} 
      />
    </Box>
  );
};

export default Transfer;